"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_groups_id(self):
        """Test case for delete_groups_id

        Removes the group with the given id  # noqa: E501
        """
        pass

    def test_get_groups(self):
        """Test case for get_groups

        Retrieves a list of groups from the groups service  # noqa: E501
        """
        pass

    def test_get_groups_id(self):
        """Test case for get_groups_id

        Retrieves a group with the given id from the service  # noqa: E501
        """
        pass

    def test_patch_groups_id(self):
        """Test case for patch_groups_id

        Updates the resource with the given id  # noqa: E501
        """
        pass

    def test_post_groups(self):
        """Test case for post_groups

        Create a new group  # noqa: E501
        """
        pass

    def test_put_groups_id(self):
        """Test case for put_groups_id

        Updates the group with given id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
