"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import kdp_api
from kdp_api.model.segment import Segment


class TestSegment(unittest.TestCase):
    """Segment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSegment(self):
        """Test Segment"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Segment()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
