"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.dataset_permissions_api import DatasetPermissionsApi  # noqa: E501


class TestDatasetPermissionsApi(unittest.TestCase):
    """DatasetPermissionsApi unit test stubs"""

    def setUp(self):
        self.api = DatasetPermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_dataset_permissions_id(self):
        """Test case for delete_dataset_permissions_id

        Remove Dataset Permission with given ID  # noqa: E501
        """
        pass

    def test_get_dataset_permissions(self):
        """Test case for get_dataset_permissions

        Retrieve list of dataset permissions  # noqa: E501
        """
        pass

    def test_get_dataset_permissions_id(self):
        """Test case for get_dataset_permissions_id

        Retrieve a Dataset Permission with the given ID  # noqa: E501
        """
        pass

    def test_patch_dataset_permissions_id(self):
        """Test case for patch_dataset_permissions_id

        Update provided fields of Dataset Permission with given ID  # noqa: E501
        """
        pass

    def test_post_dataset_permissions(self):
        """Test case for post_dataset_permissions

        Create a new Dataset Permission  # noqa: E501
        """
        pass

    def test_put_dataset_permissions_id(self):
        """Test case for put_dataset_permissions_id

        Update Dataset Permission with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
