"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.transfer_resource_requests_api import TransferResourceRequestsApi  # noqa: E501


class TestTransferResourceRequestsApi(unittest.TestCase):
    """TransferResourceRequestsApi unit test stubs"""

    def setUp(self):
        self.api = TransferResourceRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transfer_resource_requests(self):
        """Test case for get_transfer_resource_requests

        Retrieves a list of transfer resource requests  # noqa: E501
        """
        pass

    def test_get_transfer_resource_requests_id(self):
        """Test case for get_transfer_resource_requests_id

        Retrieves a transfer resource request with the given ID  # noqa: E501
        """
        pass

    def test_patch_transfer_resource_requests_id(self):
        """Test case for patch_transfer_resource_requests_id

        Patches the transfer resource request status by id  # noqa: E501
        """
        pass

    def test_post_transfer_resource_requests(self):
        """Test case for post_transfer_resource_requests

        Create a transfer resource request  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
